@@ -59,6 +59,7 @@ IceWMConfig::IceWMConfig( TDEConfig* conf, TQWidget* parent )
 	: TQObject( parent )
 {
 	icewmConfig = new TDEConfig("twinicewmrc");
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
 	TDEGlobal::locale()->insertCatalogue("twin_art_clients");
 
 	mainWidget = new TQVBox( parent );
@@ -97,12 +98,15 @@ IceWMConfig::IceWMConfig( TDEConfig* conf, TQWidget* parent )
 	urlLabel->setText( i18n("Open TDE's IceWM theme folder") );
 
 	themeLabel = new TQLabel(
-				i18n("Clicking on the link above will cause a window to appear "
-                                "showing the TDE IceWM theme folder. You can "
-				"add or remove native IceWM themes by "
-				"uncompressing <b>http://icewm.themes.org/</b> theme files "
-				"into this folder, or by creating folder symlinks to "
-				"existing IceWM themes on your system."), mainWidget );
+				i18n("Clicking on the link above will cause a window to appear showing the TDE IceWM theme folder. "
+				     "You can add or remove native IceWM themes by installing theme files into this folder or by "
+				     "creating folder symlinks to existing IceWM themes on your system. "
+				     "You can get extra-themes here: <b>https://github.com/bbidulock/icewm-extra-themes</b>"
+				), mainWidget );
+				
+	TQWhatsThis::add( themeLabel,
+	            i18n("You're supposed to copy the entire theme folders "
+	                 "into your TDE IceWM theme folder.") ); 
 
 	// Load configuration options
 	load( conf );
