@@ -11,6 +11,7 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 #include <tqdrawutil.h>
 #include <tqbitmap.h>
 #include <kdrawutil.h>
+#include <tdeglobal.h>
 #include <tdelocale.h>
 #include <kpixmap.h>
 #include <tqdatetime.h>
@@ -254,7 +255,7 @@ void StdClient::init()
     TQGridLayout* g = new TQGridLayout( widget(), 0, 0, 3, 2 );
     g->setRowStretch( 1, 10 );
     if( isPreview())
-        g->addWidget( new TQLabel( i18n( "<center><b>TDE 1 preview</b></center>" ), widget()), 1, 1 );
+        g->addWidget( new TQLabel( i18n( "<center><b>KDE 1 preview</b></center>" ), widget()), 1, 1 );
     else
         g->addItem( new TQSpacerItem( 0, 0 ), 1, 1 ); //no widget in the middle
     g->addItem( new TQSpacerItem( 0, 0, TQSizePolicy::Fixed, TQSizePolicy::Expanding ) );
@@ -282,7 +283,7 @@ void StdClient::init()
 	button[n]->setBackgroundMode( PaletteBackground );
 	button[n]->setMouseTracking( FALSE );
 	button[n]->setAutoRaise( TRUE );
-	button[n]->setFocusPolicy( TQ_NoFocus );
+	button[n]->setFocusPolicy( TQWidget::NoFocus );
 	button[n]->setFixedSize( 20, 20 );
     }
 
@@ -543,7 +544,7 @@ void StdClient::maxButtonClicked( ButtonState button )
 
 bool StdClient::eventFilter( TQObject* o, TQEvent* e )
 {
-    if ( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()) )
+    if ( o != widget() )
 	return false;
 
     switch ( e->type() ) {
@@ -603,7 +604,7 @@ void StdToolClient::init()
     TQGridLayout* g = new TQGridLayout( widget(), 0, 0, 2 );
     g->setRowStretch( 1, 10 );
     if( isPreview())
-        g->addWidget( new TQLabel( i18n( "<center><b>TDE 1 decoration</b></center>" ), widget()), 1, 1 );
+        g->addWidget( new TQLabel( i18n( "<center><b>KDE 1 decoration</b></center>" ), widget()), 1, 1 );
     else
         g->addItem( new TQSpacerItem( 0, 0 ), 1, 1 ); //no widget in the middle
     g->addItem( new TQSpacerItem( 0, 0, TQSizePolicy::Fixed, TQSizePolicy::Expanding ) );
@@ -692,7 +693,7 @@ void StdToolClient::reset( unsigned long )
 
 bool StdToolClient::eventFilter( TQObject* o, TQEvent* e )
 {
-    if ( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()) )
+    if ( o != widget() )
 	return false;
 
     switch ( e->type() ) {
@@ -739,6 +740,8 @@ void StdToolClient::resize( const TQSize& s )
 
 StdFactory::StdFactory()
 {
+    TDEGlobal::locale()->insertCatalogue("twin_clients");
+    TDEGlobal::locale()->insertCatalogue("twin_art_clients");
     create_pixmaps();
 }
 
