@@ -165,7 +165,7 @@ OpenLook::~OpenLook()
 
 bool OpenLook::eventFilter(TQObject *o, TQEvent *e)
 {
-  if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget())) return false;
+  if (o != widget()) return false;
   switch (e->type()) {
   case TQEvent::Resize:
     resizeEvent(TQT_TQRESIZEEVENT(e));
