@@ -82,7 +82,7 @@ void Manager::init()
 
 bool Manager::eventFilter(TQObject *o, TQEvent *e)
 {
-   if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget())) return false;
+   if (o != widget()) return false;
    switch (e->type())
    {
       case TQEvent::Resize:
