@@ -11,6 +11,7 @@
 #include <tdeversion.h>
 #include <tdeglobal.h>
 #include <tdeglobalsettings.h>
+#include <tdeglobal.h>
 #include <tdelocale.h>
 #include <kpixmap.h>
 #include <kimageeffect.h>
@@ -58,8 +59,12 @@ const char default_right[] = "HIAX";
 static const uint TIMERINTERVAL = 50; // msec
 static const uint ANIMATIONSTEPS = 4;
 
-extern "C" KDecorationFactory* create_factory() {
-    return new smoothblend::smoothblendFactory();
+extern "C"
+{
+	KDE_EXPORT KDecorationFactory* create_factory()
+	{
+		return new smoothblend::smoothblendFactory();
+	}
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -68,6 +73,8 @@ extern "C" KDecorationFactory* create_factory() {
 // Constructor
 
 smoothblendFactory::smoothblendFactory() {
+    TDEGlobal::locale()->insertCatalogue("twin_clients");
+    TDEGlobal::locale()->insertCatalogue("twin_art_clients");
     readConfig();
     initialized_ = true;
 }
@@ -1035,7 +1042,7 @@ KDecoration::Position smoothblendClient::mousePosition(const TQPoint &point) con
 // Event filter
 
 bool smoothblendClient::eventFilter(TQObject *obj, TQEvent *e) {
-    if (TQT_BASE_OBJECT(obj) != TQT_BASE_OBJECT(widget()))
+    if (obj != widget())
         return false;
 
     switch (e->type()) {
